document.addEventListener('DOMContentLoaded', () => {
  const themeToggle = document.getElementById('themeToggle');
  const taskDialog = document.getElementById('taskDialog');
  const taskForm = document.getElementById('taskForm');
  const addTaskBtns = document.querySelectorAll('.add-task-btn');
  
  let currentColumn = null;
  
  // Theme Management
  const setTheme = (theme) => {
    document.documentElement.setAttribute('data-theme', theme);
    localStorage.setItem('theme', theme);
  };

  themeToggle.addEventListener('click', () => {
    const currentTheme = localStorage.getItem('theme') || 'light';
    setTheme(currentTheme === 'light' ? 'dark' : 'light');
  });

  // Initialize theme
  setTheme(localStorage.getItem('theme') || 'light');

  // Dialog Management
  addTaskBtns.forEach(btn => {
    btn.addEventListener('click', () => {
      currentColumn = btn.dataset.column;
      taskDialog.showModal();
    });
  });

  document.querySelector('.cancel-btn').addEventListener('click', () => {
    taskDialog.close();
    taskForm.reset();
  });

  // Task Management
  taskForm.addEventListener('submit', (e) => {
    e.preventDefault();
    
    const task = {
      id: Date.now(),
      name: document.getElementById('taskName').value,
      description: document.getElementById('taskDescription').value,
      labels: document.getElementById('taskLabels').value.split(',').map(label => label.trim()),
      dueDate: document.getElementById('taskDueDate').value,
      color: document.getElementById('taskColor').value,
      completed: false
    };

    createTaskCard(task, currentColumn);
    taskDialog.close();
    taskForm.reset();
  });

  function createTaskCard(task, column) {
    const taskCard = document.createElement('div');
    taskCard.className = 'task-card';
    taskCard.draggable = true;
    taskCard.style.backgroundColor = task.color;
    
    taskCard.innerHTML = `
      <input type="checkbox" ${task.completed ? 'checked' : ''}>
      <h3>${task.name}</h3>
      <p>${task.description}</p>
      <div class="labels">
        ${task.labels.map(label => `<span class="label">${label}</span>`).join('')}
      </div>
      ${task.dueDate ? `<div class="due-date">Due: ${task.dueDate}</div>` : ''}
    `;

    const targetColumn = document.querySelector(`[data-column="${column}"] .task-list`);
    targetColumn.appendChild(taskCard);

    // Drag and Drop
    taskCard.addEventListener('dragstart', () => {
      taskCard.classList.add('dragging');
    });

    taskCard.addEventListener('dragend', () => {
      taskCard.classList.remove('dragging');
    });

    // Checkbox handling
    const checkbox = taskCard.querySelector('input[type="checkbox"]');
    checkbox.addEventListener('change', () => {
      if (checkbox.checked) {
        const completedList = document.querySelector('[data-column="completed"] .task-list');
        completedList.appendChild(taskCard);
        task.completed = true;
      }
    });
  }

  // Drag and Drop Logic
  document.querySelectorAll('.task-list').forEach(list => {
    list.addEventListener('dragover', e => {
      e.preventDefault();
      const draggingCard = document.querySelector('.dragging');
      const cards = [...list.querySelectorAll('.task-card:not(.dragging)')];
      const afterCard = cards.reduce((closest, card) => {
        const box = card.getBoundingClientRect();
        const offset = e.clientY - box.top - box.height / 2;
        if (offset < 0 && offset > closest.offset) {
          return { offset, element: card };
        }
        return closest;
      }, { offset: Number.NEGATIVE_INFINITY }).element;

      if (afterCard) {
        list.insertBefore(draggingCard, afterCard);
      } else {
        list.appendChild(draggingCard);
      }
    });
  });
});
